@@ -37,33 +37,25 @@ __all__ = [
 # System imports
 import sys
 
+from modelparameters.codegeneration import sympycode
+from modelparameters.logger import error, info
+
 # ModelParameters imports
 from modelparameters.sympytools import sp
-from modelparameters.codegeneration import sympycode
+from modelparameters.utils import Timer, check_arg, check_kwarg, listwrap
+from sympy import cse
 
-# Local imports
-from gotran.common import (
-    error,
-    info,
-    debug,
-    check_arg,
-    check_kwarg,
-    scalars,
-    Timer,
-    warning,
-    tuplewrap,
-    parameters,
-    warning,
+from gotran.model.expressions import (
+    AlgebraicExpression,
+    Expression,
+    IndexedExpression,
+    StateDerivative,
 )
-from gotran.common import listwrap
-from gotran.model.utils import ode_primitives
-from gotran.model.odeobjects import State, Parameter, IndexedObject, Comment
-from gotran.model.expressions import *
-from gotran.model.ode import ODE
-from gotran.codegeneration.codecomponent import CodeComponent
 
-# FIXME: Remove our own cse, or move to this module?
-from gotran.codegeneration.sympy_cse import cse
+from ..model.ode import ODE
+from ..model.odeobjects import Comment
+from ..model.utils import ode_primitives
+from .codecomponent import CodeComponent
 
 
 def rhs_expressions(ode, function_name="rhs", result_name="dy", params=None):
@@ -85,10 +77,10 @@ def rhs_expressions(ode, function_name="rhs", result_name="dy", params=None):
     check_arg(ode, ODE)
     if not ode.is_finalized:
         error(
-            "Cannot compute right hand side expressions if the ODE is " "not finalized"
+            "Cannot compute right hand side expressions if the ODE is " "not finalized",
         )
 
-    descr = "Compute the right hand side of the {0} ODE".format(ode)
+    descr = f"Compute the right hand side of the {ode} ODE"
 
     return CodeComponent(
         "RHSComponent",
@@ -96,7 +88,7 @@ def rhs_expressions(ode, function_name="rhs", result_name="dy", params=None):
         function_name,
         descr,
         params=params,
-        **{result_name: ode.state_expressions}
+        **{result_name: ode.state_expressions},
     )
 
 
@@ -127,7 +119,7 @@ def monitored_expressions(
     check_arg(ode, ODE)
     if not ode.is_finalized:
         error(
-            "Cannot compute right hand side expressions if the ODE is " "not finalized"
+            "Cannot compute right hand side expressions if the ODE is " "not finalized",
         )
 
     check_arg(monitored, (tuple, list), itemtypes=str)
@@ -135,18 +127,18 @@ def monitored_expressions(
     for expr_str in monitored:
         obj = ode.present_ode_objects.get(expr_str)
         if not isinstance(obj, Expression):
-            error("{0} is not an expression in the {1} ODE".format(expr_str, ode))
+            error(f"{expr_str} is not an expression in the {ode} ODE")
 
         monitored_exprs.append(obj)
 
-    descr = "Computes monitored expressions of the {0} ODE".format(ode)
+    descr = f"Computes monitored expressions of the {ode} ODE"
     return CodeComponent(
         "MonitoredExpressions",
         ode,
         function_name,
         descr,
         params=params,
-        **{result_name: monitored_exprs}
+        **{result_name: monitored_exprs},
     )
 
 
@@ -182,10 +174,10 @@ def componentwise_derivative(ode, indices, params=None, result_name="dy"):
         if index < 0 or index >= ode.num_full_states:
             error(
                 "Expected the passed indices to be between 0 and the "
-                "number of states in the ode, got {0}.".format(index)
+                "number of states in the ode, got {0}.".format(index),
             )
         if index in registered:
-            error("Index {0} appeared twice.".format(index))
+            error(f"Index {index} appeared twice.")
 
         registered.append(index)
 
@@ -195,14 +187,12 @@ def componentwise_derivative(ode, indices, params=None, result_name="dy"):
     results = {result_name: exprs}
 
     return CodeComponent(
-        "componentwise_derivatives_{0}".format(
-            "_".join(expr.state.name for expr in exprs)
-        ),
+        f"componentwise_derivatives_{'_'.join(expr.state.name for expr in exprs)}",
         ode,
         "",
         "",
         params=params,
-        **results
+        **results,
     )
 
 
@@ -251,7 +241,10 @@ def linearized_derivatives(
 
 
 def jacobian_expressions(
-    ode, function_name="compute_jacobian", result_name="jac", params=None
+    ode,
+    function_name="compute_jacobian",
+    result_name="jac",
+    params=None,
 ):
     """
     Return an ODEComponent holding expressions for the jacobian
@@ -271,7 +264,10 @@ def jacobian_expressions(
         error("The ODE is not finalized")
 
     return JacobianComponent(
-        ode, function_name=function_name, result_name=result_name, params=params
+        ode,
+        function_name=function_name,
+        result_name=result_name,
+        params=params,
     )
 
 
@@ -301,7 +297,11 @@ def jacobian_action_expressions(
 
     check_arg(jacobian, JacobianComponent)
     return JacobianActionComponent(
-        jacobian, with_body, function_name, result_name, params=params
+        jacobian,
+        with_body,
+        function_name,
+        result_name,
+        params=params,
     )
 
 
@@ -326,7 +326,10 @@ def diagonal_jacobian_expressions(
         Parameters determining how the code should be generated
     """
     return DiagonalJacobianComponent(
-        jacobian, function_name, result_name, params=params
+        jacobian,
+        function_name,
+        result_name,
+        params=params,
     )
 
 
@@ -356,12 +359,18 @@ def diagonal_jacobian_action_expressions(
 
     check_arg(diagonal_jacobian, DiagonalJacobianComponent)
     return DiagonalJacobianActionComponent(
-        diagonal_jacobian, with_body, function_name, result_name, params=params
+        diagonal_jacobian,
+        with_body,
+        function_name,
+        result_name,
+        params=params,
     )
 
 
 def factorized_jacobian_expressions(
-    jacobian, function_name="lu_factorize", params=None
+    jacobian,
+    function_name="lu_factorize",
+    params=None,
 ):
     """
     Return an ODEComponent holding expressions for the factorized jacobian
@@ -417,7 +426,11 @@ class JacobianComponent(CodeComponent):
     """
 
     def __init__(
-        self, ode, function_name="compute_jacobian", result_name="jac", params=None
+        self,
+        ode,
+        function_name="compute_jacobian",
+        result_name="jac",
+        params=None,
     ):
         """
         Create a JacobianComponent
@@ -436,15 +449,17 @@ class JacobianComponent(CodeComponent):
         check_arg(ode, ODE)
 
         # Call base class using empty result_expressions
-        descr = "Compute the jacobian of the right hand side of the " "{0} ODE".format(
-            ode
-        )
+        descr = f"Compute the jacobian of the right hand side of the {ode} ODE"
         super(JacobianComponent, self).__init__(
-            "Jacobian", ode, function_name, descr, params=params
+            "Jacobian",
+            ode,
+            function_name,
+            descr,
+            params=params,
         )
         check_arg(result_name, str)
 
-        timer = Timer("Computing jacobian")
+        timer = Timer("Computing jacobian")  # noqa:F841
 
         # Gather state expressions and states
         state_exprs = self.root.state_expressions
@@ -464,9 +479,7 @@ class JacobianComponent(CodeComponent):
         might_take_time = N >= 10
 
         if might_take_time:
-            info(
-                "Calculating Jacobian of {0}. Might take some time...".format(ode.name)
-            )
+            info(f"Calculating Jacobian of {ode.name}. Might take some time...")
             sys.stdout.flush()
 
         for i, expr in enumerate(state_exprs):
@@ -478,8 +491,7 @@ class JacobianComponent(CodeComponent):
             )
 
             self.add_comment(
-                "Expressions for the sparse jacobian of "
-                "state {0}".format(expr.state.name),
+                f"Expressions for the sparse jacobian of state {expr.state.name}",
                 dependent=expr,
             )
 
@@ -489,7 +501,10 @@ class JacobianComponent(CodeComponent):
                 del time_diff
                 self.num_nonzero += 1
                 jac_ij = self.add_indexed_expression(
-                    result_name, (i, j), jac_ij, dependent=expr
+                    result_name,
+                    (i, j),
+                    jac_ij,
+                    dependent=expr,
                 )
 
                 self.jacobian[i, j] = jac_ij
@@ -537,11 +552,15 @@ class DiagonalJacobianComponent(CodeComponent):
             "{0} ODE".format(jacobian.root)
         )
         super(DiagonalJacobianComponent, self).__init__(
-            "DiagonalJacobian", jacobian.root, function_name, descr, params=params
+            "DiagonalJacobian",
+            jacobian.root,
+            function_name,
+            descr,
+            params=params,
         )
 
         what = "Computing diagonal jacobian"
-        timer = Timer(what)
+        timer = Timer(what)  # noqa: F841
 
         self.add_comment(what)
 
@@ -595,14 +614,18 @@ class JacobianActionComponent(CodeComponent):
         params : dict
             Parameters determining how the code should be generated
         """
-        timer = Timer("Computing jacobian action component")
+        timer = Timer("Computing jacobian action component")  # noqa: F841
         check_arg(jacobian, JacobianComponent)
         descr = (
             "Compute the jacobian action of the right hand side of the "
             "{0} ODE".format(jacobian.root)
         )
         super(JacobianActionComponent, self).__init__(
-            "JacobianAction", jacobian.root, function_name, descr, params=params
+            "JacobianAction",
+            jacobian.root,
+            function_name,
+            descr,
+            params=params,
         )
 
         x = self.root.full_state_vector
@@ -659,7 +682,7 @@ class DiagonalJacobianActionComponent(CodeComponent):
         params : dict
             Parameters determining how the code should be generated
         """
-        timer = Timer("Computing jacobian action component")
+        timer = Timer("Computing jacobian action component")  # noqa: F841
         check_arg(diagonal_jacobian, DiagonalJacobianComponent)
         descr = (
             "Compute the diagonal jacobian action of the right hand side "
@@ -715,11 +738,9 @@ class FactorizedJacobianComponent(CodeComponent):
             Parameters determining how the code should be generated
         """
 
-        timer = Timer("Computing factorization of jacobian")
+        timer = Timer("Computing factorization of jacobian")  # noqa: F841
         check_arg(jacobian, JacobianComponent)
-        descr = "Symbolically factorize the jacobian of the {0} ODE".format(
-            jacobian.root
-        )
+        descr = f"Symbolically factorize the jacobian of the {jacobian.root} ODE"
         super(FactorizedJacobianComponent, self).__init__(
             "FactorizedJacobian",
             jacobian.root,
@@ -730,7 +751,7 @@ class FactorizedJacobianComponent(CodeComponent):
             additional_arguments=jacobian.results,
         )
 
-        self.add_comment("Factorizing jacobian of {0}".format(self.root.name))
+        self.add_comment(f"Factorizing jacobian of {self.root.name}")
 
         jacobian_name = jacobian.results[0]
 
@@ -863,10 +884,9 @@ class ForwardBackwardSubstitutionComponent(CodeComponent):
         params : dict
             Parameters determining how the code should be generated
         """
-        timer = Timer("Computing forward backward substituion component")
+        timer = Timer("Computing forward backward substituion component")  # noqa: F841
         check_arg(factorized, FactorizedJacobianComponent)
         jacobian_name = list(factorized.shapes.keys())[0]
-        additional_indexed_arguments = factorized.additional_arguments + [residual_name]
         descr = (
             "Symbolically forward backward substitute linear system "
             "of {0} ODE".format(factorized.root)
@@ -882,8 +902,7 @@ class ForwardBackwardSubstitutionComponent(CodeComponent):
         )
 
         self.add_comment(
-            "Forward backward substituting factorized "
-            "linear system {0}".format(self.root.name)
+            f"Forward backward substituting factorized linear system {self.root.name}",
         )
 
         # Recreate jacobian using only sympy Symbols
@@ -924,7 +943,9 @@ class ForwardBackwardSubstitutionComponent(CodeComponent):
                 if jac[i, j].is_zero:
                     continue
                 dx[i] = self.add_indexed_expression(
-                    result_name, i, dx[i] - dx[j] * jac[i, j]
+                    result_name,
+                    i,
+                    dx[i] - dx[j] * jac[i, j],
                 )
 
         # backward substitution
@@ -933,7 +954,9 @@ class ForwardBackwardSubstitutionComponent(CodeComponent):
                 if jac[i, j].is_zero:
                     continue
                 dx[i] = self.add_indexed_expression(
-                    result_name, i, dx[i] - dx[j] * jac[i, j]
+                    result_name,
+                    i,
+                    dx[i] - dx[j] * jac[i, j],
                 )
 
             dx[i] = self.add_indexed_expression(result_name, i, dx[i] / jac[i, i])
@@ -991,7 +1014,11 @@ class LinearizedDerivativeComponent(CodeComponent):
 
         descr = "Computes the linearized derivatives for all linear derivatives"
         super(LinearizedDerivativeComponent, self).__init__(
-            "LinearizedDerivatives", ode, function_name, descr, params=params
+            "LinearizedDerivatives",
+            ode,
+            function_name,
+            descr,
+            params=params,
         )
 
         check_arg(ode, ODE)
@@ -1020,14 +1047,20 @@ class LinearizedDerivativeComponent(CodeComponent):
                 nonlinear_exprs.append((linearized_name, ind, expr_diff))
             else:
                 self.add_indexed_expression(
-                    linearized_name, ind, expr_diff, dependent=expr
+                    linearized_name,
+                    ind,
+                    expr_diff,
+                    dependent=expr,
                 )
 
         if nonlinear_exprs:
             self.add_comment("Nonlinear linearized expressions", dependent=expr)
             for linearized_name, ind, expr_diff in nonlinear_exprs:
                 self.add_indexed_expression(
-                    linearized_name, ind, expr_diff, dependent=expr
+                    linearized_name,
+                    ind,
+                    expr_diff,
+                    dependent=expr,
                 )
 
         # Call recreate body with the jacobian action expressions as the
@@ -1050,7 +1083,7 @@ class CommonSubExpressionODE(ODE):
         check_arg(ode, ODE)
         assert ode.is_finalized
 
-        timer = Timer("Extract common sub expressions")
+        timer = Timer("Extract common sub expressions")  # noqa: F841
 
         newname = ode.name + "_CSE"
 
@@ -1073,7 +1106,9 @@ class CommonSubExpressionODE(ODE):
 
         # Call sympy common sub expression reduction
         cse_exprs, cse_state_exprs = cse(
-            expanded_state_exprs, symbols=sp.numbered_symbols("cse_"), optimizations=[]
+            expanded_state_exprs,
+            symbols=sp.numbered_symbols("cse_"),
+            optimizations=[],
         )
         cse_cnt = 0
         cse_subs = {}
@@ -1087,7 +1122,8 @@ class CommonSubExpressionODE(ODE):
                 cse_subs[sub] = expr
             else:
                 cse_subs[sub] = self.add_intermediate(
-                    "cse_{0}".format(cse_cnt), expr.xreplace(cse_subs)
+                    f"cse_{cse_cnt}",
+                    expr.xreplace(cse_subs),
                 )
                 cse_cnt += 1
 
