@@ -14,30 +14,34 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with Gotran. If not, see <http://www.gnu.org/licenses/>.
-
 # FIXME: This is a deprecated module. Most of it should be
 # incorporated into other modules by now.
-
-# System imports
-from collections import deque, OrderedDict
 import hashlib
 import re
 import sys
+from collections import OrderedDict
 from distutils.version import LooseVersion as _V
 
+import sympy
+from modelparameters.logger import info
+from modelparameters.parameterdict import Param
+from modelparameters.parameterdict import ParameterDict
+from modelparameters.parameterdict import ScalarParam
+from modelparameters.sympytools import iter_symbol_params_from_expr
+from modelparameters.sympytools import sp
+from modelparameters.utils import check_arg
+from modelparameters.utils import check_kwarg
+from sympy import cse
+
+from ..model.ode import ODE
+from ..model.odecomponent import Comment
+from ..model.odecomponent import ODEComponent
+
+# System imports
 # Model parametrs imports
-from modelparameters.parameterdict import *
-from modelparameters.sympytools import sp, iter_symbol_params_from_expr
+# Local gotran imports
 
 _current_sympy_version = _V(sp.__version__)
-
-# Local gotran imports
-from gotran.model.ode import ODE
-from gotran.model.odecomponent import ODEComponent, Comment
-from gotran.common import check_arg, check_kwarg, info
-
-from .sympy_cse import cse
-
 _jacobian_pattern = re.compile("_([0-9]+)")
 
 
@@ -75,14 +79,16 @@ def _default_params(exclude=None):
     if "keep_intermediates" not in exclude:
         # Keep all intermediates
         params["keep_intermediates"] = Param(
-            True, description="Keep intermediates in code"
+            True,
+            description="Keep intermediates in code",
         )
 
     if "use_variables" not in exclude:
         # If True, code for altering variables are created
         # FIXME: Not used
         params["use_variables"] = Param(
-            False, description="If True, code for altering variables are created"
+            False,
+            description="If True, code for altering variables are created",
         )
 
     if "parameter_contraction" not in exclude:
@@ -124,25 +130,29 @@ def _default_params(exclude=None):
     if "generate_jacobian" not in exclude:
         # Generate code for the computation of the jacobian
         params["generate_jacobian"] = Param(
-            True, description="Generate code for the computation of the jacobian"
+            True,
+            description="Generate code for the computation of the jacobian",
         )
 
     if "transposed_jacobian" not in exclude:
         # Generate code for the computation of the jacobian
         params["transposed_jacobian"] = Param(
-            False, description="The Jacobian is transposed"
+            False,
+            description="The Jacobian is transposed",
         )
 
     if "generate_lu_factorization" not in exclude:
         # Generate code for the factorization of the jacobian
         params["generate_lu_factorization"] = Param(
-            True, description="Generate code for the factorization of the jacobian"
+            True,
+            description="Generate code for the factorization of the jacobian",
         )
 
     if "generate_forward_backward_subst" not in exclude:
         # Generate code for the forward backward substitution code
         params["generate_forward_backward_subst"] = Param(
-            True, description="Generate code for the forward backward substitution code"
+            True,
+            description="Generate code for the forward backward substitution code",
         )
 
     if "generate_linearized_evaluation" not in exclude:
@@ -190,7 +200,7 @@ class ODERepresentation(object):
 
         self.optimization.update(optimization)
         self._symbol_subs = None
-        self.index = lambda i: "[{0}]".format(i)
+        self.index = lambda i: f"[{i}]"
 
         # Init prefix info
         self._state_prefix = ""
@@ -312,7 +322,7 @@ class ODERepresentation(object):
         self._cse_monitored_counts = cse_counts
 
         self._used_in_monitoring["parameters"] = list(
-            self._used_in_monitoring["parameters"]
+            self._used_in_monitoring["parameters"],
         )
 
         self._used_in_monitoring["states"] = list(self._used_in_monitoring["states"])
@@ -326,7 +336,7 @@ class ODERepresentation(object):
         if ode.num_states > 10:
             info(
                 "Calculating jacobian for {0} states. "
-                "May take some time...".format(ode.num_states)
+                "May take some time...".format(ode.num_states),
             )
             sys.stdout.flush()
 
@@ -338,7 +348,7 @@ class ODERepresentation(object):
 
                 # Only collect non zero contributions
                 if F_ij:
-                    jacobi_sym = sp.Symbol("j_{0}_{1}".format(i, j))
+                    jacobi_sym = sp.Symbol(f"j_{i}_{j}")
                     sym_map[i, j] = jacobi_sym
                     jacobi_expr[jacobi_sym] = F_ij
                     # print "[%d,%d] (%d) # [%s, %s]  \n%s" \
@@ -346,7 +356,9 @@ class ODERepresentation(object):
 
         # Create the Jacobian
         self._jacobian_mat = sp.SparseMatrix(
-            ode.num_states, ode.num_states, lambda i, j: sym_map.get((i, j), 0)
+            ode.num_states,
+            ode.num_states,
+            lambda i, j: sym_map.get((i, j), 0),
         )
 
         if self.optimization.transposed_jacobian:
@@ -380,7 +392,7 @@ class ODERepresentation(object):
 
         info(
             "Calculating jacobian action common sub expressions for {0} entries. "
-            "May take some time...".format(len(self._jacobian_action_expr))
+            "May take some time...".format(len(self._jacobian_action_expr)),
         )
         sys.stdout.flush()
 
@@ -410,7 +422,7 @@ class ODERepresentation(object):
                     in self._cse_jacobian_action_expr[j].atoms()
                 ):
                     cse_jacobian_action_counts[i].append(
-                        j + len(self._cse_jacobian_action_subs)
+                        j + len(self._cse_jacobian_action_subs),
                     )
 
         # Store usage count
@@ -428,7 +440,7 @@ class ODERepresentation(object):
 
         info(
             "Calculating jacobi common sub expressions for {0} entries. "
-            "May take some time...".format(len(self._jacobian_expr))
+            "May take some time...".format(len(self._jacobian_expr)),
         )
         sys.stdout.flush()
 
@@ -468,7 +480,7 @@ class ODERepresentation(object):
         AA = self._jacobian_mat
 
         if not AA.is_square:
-            raise NonSquareMatrixError()
+            raise sympy.NonSquareMatrixError()
 
         # Get copy
         n = AA.rows
@@ -508,15 +520,18 @@ class ODERepresentation(object):
             if i != 0:
                 operations.append(
                     "jac[{i}*{n}+{j}] -= jac[{i}*{n}+{k}]*jac[{k}*{n}+{j}]".format(
-                        i=i, j=j, k=k, n=n
-                    )
+                        i=i,
+                        j=j,
+                        k=k,
+                        n=n,
+                    ),
                 )
             else:
                 operations.append(
-                    "jac[{j}] -= jac[{k}]*jac[{k}*{n}+{j}]".format(j=j, k=k, n=n)
+                    "jac[{j}] -= jac[{k}]*jac[{k}*{n}+{j}]".format(j=j, k=k, n=n),
                 )
 
-            new_sym = sp.Symbol("j_{0}_{1}:{2}".format(i, j, new_count))
+            new_sym = sp.Symbol(f"j_{i}_{j}:{new_count}")
             new_old[new_sym] = A[i, j] - A[i, k] * A[k, j]
             for old_sym in [A[i, j], A[i, k], A[k, j]]:
                 storage = old_new.get(old_sym)
@@ -564,11 +579,11 @@ class ODERepresentation(object):
 
                 # Store operation
                 operations.append(
-                    "jac[{i}*{n}+{j}] /= jac[{j}*{n}+{j}]".format(i=i, n=n, j=j)
+                    "jac[{i}*{n}+{j}] /= jac[{j}*{n}+{j}]".format(i=i, n=n, j=j),
                 )
 
                 # Create new symbol and store the representation
-                new_sym = sp.Symbol("j_{0}_{1}:{2}".format(i, j, new_count))
+                new_sym = sp.Symbol(f"j_{i}_{j}:{new_count}")
                 new_old[new_sym] = A[i, j] * scale
                 for old_sym in [A[i, j], A[j, j]]:
                     storage = old_new.get(old_sym)
@@ -606,7 +621,6 @@ class ODERepresentation(object):
                 int(zero_operations * 1.0 / total_op * 100),
                 "%",
             )
-        factorizing_nnz_operations = new_count
 
         self._jacobian_factorization_operations = operations
         self._factorized_jacobian = A
@@ -625,7 +639,7 @@ class ODERepresentation(object):
         A = self._factorized_jacobian
 
         n = A.rows
-        b = sp.Matrix(n, 1, lambda i, j: sp.Symbol("F_{}".format(i)))
+        b = sp.Matrix(n, 1, lambda i, j: sp.Symbol(f"F_{i}"))
 
         old_new = OrderedDict()
         new_old = OrderedDict()
@@ -643,13 +657,13 @@ class ODERepresentation(object):
 
             if i != 0:
                 operations.append(
-                    "dx[{i}] -= dx[{j}]*jac[{i}*{n}+{j}]".format(i=i, j=j, n=n)
+                    "dx[{i}] -= dx[{j}]*jac[{i}*{n}+{j}]".format(i=i, j=j, n=n),
                 )
             else:
                 operations.append("dx[{i}] -= dx[{j}]*jac[{j}]".format(i=i, j=j))
 
             # Create new symbol and store the representation
-            new_sym = sp.Symbol("F_{0}:{1}".format(i, new_count))
+            new_sym = sp.Symbol(f"F_{i}:{new_count}")
             new_old[new_sym] = b[i, 0] - b[j, 0] * A[i, j]
             for old_sym in [b[i, 0], b[j, 0], A[i, j]]:
                 storage = old_new.get(old_sym)
@@ -703,7 +717,7 @@ class ODERepresentation(object):
             return
 
         info(
-            "Calculating common sub expressions for single components of ODE. May take some time..."
+            "Calculating common sub expressions for single components of ODE. May take some time...",
         )
         sys.stdout.flush()
         ode = self.ode
@@ -715,7 +729,7 @@ class ODERepresentation(object):
         for i, (ders, expr) in enumerate(ode.get_derivative_expr(True)):
             cse_subs, cse_derivative_expr = cse(
                 self.subs(expr),
-                symbols=sp.numbered_symbols("cse_der_{0}_".format(i)),
+                symbols=sp.numbered_symbols(f"cse_der_{i}_"),
                 optimizations=[],
             )
             self._cse_subs_single_dy.append(cse_subs)
@@ -723,7 +737,7 @@ class ODERepresentation(object):
 
         info(" done")
         info(
-            "Calculating common sub expressions for linearized ODE. May take some time..."
+            "Calculating common sub expressions for linearized ODE. May take some time...",
         )
         self._cse_linearized_subs, self._cse_linearized_derivative_expr = cse(
             [self.subs(expr) for expr in list(self._linearized_exprs.values())],
@@ -755,7 +769,7 @@ class ODERepresentation(object):
                     used_parameters.add(sym.name)
 
             used_in_single_dy.append(
-                dict(parameters=list(used_parameters), states=list(used_states))
+                dict(parameters=list(used_parameters), states=list(used_states)),
             )
 
             assert len(ders) == 1
@@ -805,7 +819,7 @@ class ODERepresentation(object):
 
     def set_state_prefix(self, prefix):
         """
-        Register a prefix to a state name. Used if 
+        Register a prefix to a state name. Used if
         """
         check_arg(prefix, str)
         self._state_prefix = prefix
@@ -815,7 +829,7 @@ class ODERepresentation(object):
 
     def set_parameter_prefix(self, prefix):
         """
-        Register a prefix to a parameter name. Used if 
+        Register a prefix to a parameter name. Used if
         """
         check_arg(prefix, str)
         self._parameter_prefix = prefix
@@ -853,7 +867,7 @@ class ODERepresentation(object):
                 subs.extend(
                     (
                         param.sym,
-                        sp.Symbol("{0}{1}".format(self._parameter_prefix, param.name)),
+                        sp.Symbol(f"{self._parameter_prefix}{param.name}"),
                     )
                     for param in self.ode.parameters
                 )
@@ -869,7 +883,7 @@ class ODERepresentation(object):
                 subs.extend(
                     (
                         param.sym,
-                        sp.Symbol("{0}{1}".format(self._state_prefix, param.name)),
+                        sp.Symbol(f"{self._state_prefix}{param.name}"),
                     )
                     for param in self.ode.states
                 )
@@ -905,7 +919,8 @@ class ODERepresentation(object):
             return (
                 (derivatives, cse_expr)
                 for ((derivatives, expr), cse_expr) in zip(
-                    self.ode.get_derivative_expr(), self._cse_derivative_expr
+                    self.ode.get_derivative_expr(),
+                    self._cse_derivative_expr,
                 )
             )
 
@@ -936,7 +951,7 @@ class ODERepresentation(object):
 
     def iter_jacobian_body(self):
         """
-        Iterate over the body defining the jacobi expressions 
+        Iterate over the body defining the jacobi expressions
         """
 
         if not self.optimization.use_cse:
@@ -947,14 +962,15 @@ class ODERepresentation(object):
         # Yield the CSE
         yield "Common Sub Expressions for jacobi intermediates", "COMMENT"
         for (name, expr), cse_count in zip(
-            self._cse_jacobian_subs, self._cse_jacobian_counts
+            self._cse_jacobian_subs,
+            self._cse_jacobian_counts,
         ):
             if cse_count:
                 yield expr, name
 
     def iter_jacobian_expr(self):
         """
-        Iterate over the jacobi expressions 
+        Iterate over the jacobi expressions
         """
 
         self._compute_jacobian_cse()
@@ -962,19 +978,20 @@ class ODERepresentation(object):
         if self.optimization.use_cse:
 
             for ((name, expr), cse_expr) in zip(
-                list(self._jacobian_expr.items()), self._cse_jacobian_expr
+                list(self._jacobian_expr.items()),
+                self._cse_jacobian_expr,
             ):
                 yield list(map(int, re.findall(_jacobian_pattern, str(name)))), cse_expr
         else:
 
             for name, expr in list(self._jacobian_expr.items()):
                 yield list(
-                    map(int, re.findall(_jacobian_pattern, str(name)))
+                    map(int, re.findall(_jacobian_pattern, str(name))),
                 ), self.subs(expr)
 
     def iter_jacobian_action_body(self):
         """
-        Iterate over the body defining the jacobi expressions 
+        Iterate over the body defining the jacobi expressions
         """
 
         if not self.optimization.use_cse:
@@ -985,14 +1002,15 @@ class ODERepresentation(object):
         # Yield the CSE
         yield "Common Sub Expressions for jacobi action intermediates", "COMMENT"
         for (name, expr), cse_count in zip(
-            self._cse_jacobian_action_subs, self._cse_jacobian_action_counts
+            self._cse_jacobian_action_subs,
+            self._cse_jacobian_action_counts,
         ):
             if cse_count:
                 yield expr, name
 
     def iter_jacobian_action_expr(self):
         """
-        Iterate over the jacobi expressions 
+        Iterate over the jacobi expressions
         """
 
         self._compute_jacobian_action_cse()
@@ -1008,7 +1026,7 @@ class ODERepresentation(object):
 
     def iter_monitored_body(self):
         """
-        Iterate over the body defining the monitored expressions 
+        Iterate over the body defining the monitored expressions
         """
 
         self._compute_monitor_cse()
@@ -1018,14 +1036,15 @@ class ODERepresentation(object):
         # Yield the CSE
         yield "Common Sub Expressions for monitored intermediates", "COMMENT"
         for (name, expr), cse_count in zip(
-            self._cse_monitored_subs, self._cse_monitored_counts
+            self._cse_monitored_subs,
+            self._cse_monitored_counts,
         ):
             if cse_count:
                 yield expr, name
 
     def iter_monitored_expr(self):
         """
-        Iterate over the monitored expressions 
+        Iterate over the monitored expressions
         """
 
         self._compute_monitor_cse()
@@ -1035,7 +1054,8 @@ class ODERepresentation(object):
         yield "COMMENT", "Monitored intermediates"
 
         for (name, cse_expr) in zip(
-            self.ode.monitored_intermediates, self._cse_monitored_expr
+            self.ode.monitored_intermediates,
+            self._cse_monitored_expr,
         ):
             yield name, cse_expr
 
@@ -1055,7 +1075,8 @@ class ODERepresentation(object):
         if self.optimization.use_cse:
             self._compute_linearized_dy_cse()
             for idx, cse_expr in zip(
-                self._linearized_exprs, self._cse_linearized_derivative_expr
+                self._linearized_exprs,
+                self._cse_linearized_derivative_expr,
             ):
                 yield idx, cse_expr
 
@@ -1069,7 +1090,8 @@ class ODERepresentation(object):
         if self.optimization.use_cse:
             self._compute_linearized_dy_cse()
             for subs, expr in zip(
-                self._cse_subs_single_dy, self._cse_derivative_expr_single_dy
+                self._cse_subs_single_dy,
+                self._cse_derivative_expr_single_dy,
             ):
                 yield subs, expr[0]
 
