@@ -17,23 +17,38 @@
 
 __all__ = ["ODE"]
 
-# System imports
-from collections import defaultdict
 import weakref
+from collections import defaultdict
 from functools import cmp_to_key
 
-from sympy.core.function import AppliedUndef
+# System imports
+from pathlib import Path
+
+from modelparameters.codegeneration import sympycode
+
+# Local imports
+from modelparameters.logger import debug, error
 
 # ModelParameters imports
 from modelparameters.sympytools import sp
-from modelparameters.codegeneration import sympycode, pythoncode
-from modelparameters.utils import Timer
+from modelparameters.utils import Timer, check_arg
+from sympy.core.function import AppliedUndef
 
-# Local imports
-from gotran.common import error, debug, check_arg, check_kwarg, scalars
-from gotran.model.odeobjects import *
-from gotran.model.expressions import *
-from gotran.model.odecomponent import *
+from .expressions import (
+    AlgebraicExpression,
+    DerivativeExpression,
+    Derivatives,
+    Expression,
+    Intermediate,
+    RateExpression,
+    State,
+    StateDerivative,
+    StateExpression,
+    StateSolution,
+    recreate_expression,
+)
+from .odecomponent import Comment, ODEComponent
+from .odeobjects import Dt, Parameter, Time, cmp
 
 
 class ODE(ODEComponent):
@@ -122,6 +137,28 @@ class ODE(ODEComponent):
         # Turn on magic attributes (see __setattr__ method)
         self._allow_magic_attributes = True
 
+    @property
+    def parameter_symbols(self):
+        return [s.name for s in self.parameters]
+
+    @property
+    def component_names(self):
+        return [s.name for s in self.components]
+
+    def parameter_values(self):
+        return [s.value for s in self.parameters]
+
+    @property
+    def state_symbols(self):
+        return [s.name for s in self.states]
+
+    def state_values(self):
+        return [s.value for s in self.states]
+
+    @property
+    def intermediate_symbols(self):
+        return [i.name for i in self.intermediates]
+
     @property
     def ns(self):
         if isinstance(self._ns, dict):
@@ -162,15 +199,15 @@ class ODE(ODEComponent):
             Optional arguments which can control loading of model
         """
 
-        timer = Timer("Import ode")
+        timer = Timer("Import ode")  # noqa: F841
 
         components = components or []
-        check_arg(ode, (str, ODE), 0, context=ODE.import_ode)
+        check_arg(ode, (str, Path, ODE), 0, context=ODE.import_ode)
         check_arg(prefix, str, 1, context=ODE.import_ode)
         check_arg(components, list, 2, context=ODE.import_ode, itemtypes=str)
 
         # If ode is given directly
-        if isinstance(ode, str):
+        if isinstance(ode, (str, Path)):
             # If not load external ODE
             from gotran.model.loadmodel import load_ode
 
@@ -243,7 +280,7 @@ class ODE(ODEComponent):
 
             comp = ode.all_components[comp_name]
 
-            comp_comment = "Expressions for the {0} " "component".format(comp.name)
+            comp_comment = f"Expressions for the {comp.name} component"
 
             # Get corresponding component in new ODE
             added = old_new_map[comp]
@@ -270,7 +307,9 @@ class ODE(ODEComponent):
 
                             states = obj.states
                             added._add_single_rate(
-                                subs[states[0].sym], subs[states[1].sym], new_expr
+                                subs[states[0].sym],
+                                subs[states[1].sym],
+                                new_expr,
                             )
                             continue
 
@@ -289,7 +328,9 @@ class ODE(ODEComponent):
 
                         elif isinstance(obj, StateDerivative):
                             subs[obj.sym] = added.add_derivative(
-                                state, added.t, new_expr
+                                state,
+                                added.t,
+                                new_expr,
                             )
 
                         elif isinstance(obj, StateSolution):
@@ -311,7 +352,7 @@ class ODE(ODEComponent):
 
                             # If not found try prefixed version
                             der_expr = self.root.present_ode_objects.get(
-                                prefix + obj.der_expr.name
+                                prefix + obj.der_expr.name,
                             )
 
                             if der_expr is None:
@@ -319,14 +360,14 @@ class ODE(ODEComponent):
                                     error(
                                         "Could not find expression: "
                                         "({0}){1} while adding "
-                                        "derivative".format(prefix, obj.der_expr)
+                                        "derivative".format(prefix, obj.der_expr),
                                     )
                                 else:
                                     error(
                                         "Could not find expression: "
-                                        "{1} while adding derivative".format(
-                                            obj.der_expr
-                                        )
+                                        "{0} while adding derivative".format(
+                                            obj.der_expr,
+                                        ),
                                     )
 
                         dep_var = self.root.present_ode_objects.get(obj.dep_var.name)
@@ -338,7 +379,7 @@ class ODE(ODEComponent):
 
                             # If not found try prefixed version
                             dep_var = self.root.present_ode_objects.get(
-                                prefix + obj.dep_var.name
+                                prefix + obj.dep_var.name,
                             )
 
                             if dep_var is None:
@@ -346,24 +387,27 @@ class ODE(ODEComponent):
                                     error(
                                         "Could not find expression: "
                                         "({0}){1} while adding "
-                                        "derivative".format(prefix, obj.dep_var)
+                                        "derivative".format(prefix, obj.dep_var),
                                     )
                                 else:
                                     error(
                                         "Could not find expression: "
-                                        "{1} while adding derivative".format(
-                                            obj.dep_var
-                                        )
+                                        "{0} while adding derivative".format(
+                                            obj.dep_var,
+                                        ),
                                     )
 
                         subs[obj.sym] = added.add_derivative(
-                            der_expr, dep_var, new_expr
+                            der_expr,
+                            dep_var,
+                            new_expr,
                         )
 
                     elif isinstance(obj, Intermediate):
 
                         subs[obj.sym] = added.add_intermediate(
-                            prefix + obj.name, new_expr
+                            prefix + obj.name,
+                            new_expr,
                         )
 
                     else:
@@ -384,7 +428,7 @@ class ODE(ODEComponent):
             given the basename will be the same as the name of the ode.
         """
 
-        timer = Timer("Save " + self.name)
+        timer = Timer("Save " + self.name)  # noqa: F841
 
         if not self._is_finalized_ode:
             error("ODE need to be finalized to be saved to file.")
@@ -404,26 +448,26 @@ class ODE(ODEComponent):
                 while present_comp.parent != self:
                     present_comp = present_comp.parent
                     comps.append(present_comp.name)
-                comp_name = ", ".join('"{0}"'.format(name) for name in reversed(comps))
+                comp_name = ", ".join(f'"{name}"' for name in reversed(comps))
 
             comp_names[comp] = comp_name
 
             states = [
-                "{0}={1},".format(obj.name, obj.param.repr(include_name=False))
+                f"{obj.name}={obj.param.repr(include_name=False)},"
                 for obj in comp.ode_objects
                 if isinstance(obj, State)
             ]
             parameters = [
-                "{0}={1},".format(obj.name, obj.param.repr(include_name=False))
+                f"{obj.name}={obj.param.repr(include_name=False)},"
                 for obj in comp.ode_objects
                 if isinstance(obj, Parameter)
             ]
             if states:
                 lines.append("")
                 if comp_name:
-                    lines.append("states({0},".format(comp_name))
+                    lines.append(f"states({comp_name},")
                 else:
-                    lines.append("states({0}".format(states.pop(0)))
+                    lines.append(f"states({states.pop(0)}")
                 for state_code in states:
                     lines.append("       " + state_code)
                 lines[-1] = lines[-1][:-1] + ")"
@@ -431,9 +475,9 @@ class ODE(ODEComponent):
             if parameters:
                 lines.append("")
                 if comp_name:
-                    lines.append("parameters({0},".format(comp_name))
+                    lines.append(f"parameters({comp_name},")
                 else:
-                    lines.append("parameters({0}".format(parameters.pop(0)))
+                    lines.append(f"parameters({parameters.pop(0)}")
                 for param_code in parameters:
                     lines.append("           " + param_code)
                 lines[-1] = lines[-1][:-1] + ")"
@@ -443,7 +487,7 @@ class ODE(ODEComponent):
 
             comp = self.all_components[comp_name]
 
-            comp_comment = "Expressions for the {0} " "component".format(comp.name)
+            comp_comment = f"Expressions for the {comp.name} component"
 
             # Iterate over all objects of the component and save only expressions
             # and comments
@@ -466,12 +510,12 @@ class ODE(ODEComponent):
                                     sympycode(obj.states[0]),
                                     sympycode(obj.states[1]),
                                     sympycode(obj.expr),
-                                )
+                                ),
                             )
                             continue
 
                     # All other Expressions
-                    lines.append("{0} = {1}".format(obj.name, sympycode(obj.expr)))
+                    lines.append(f"{obj.name} = {sympycode(obj.expr)}")
 
                 # If saving a comment
                 elif isinstance(obj, Comment):
@@ -480,16 +524,14 @@ class ODE(ODEComponent):
                     if str(obj) == comp_comment:
                         lines.append("")
                         comp_name = (
-                            comp_names[comp]
-                            if comp_names[comp]
-                            else '"{0}"'.format(basename)
+                            comp_names[comp] if comp_names[comp] else f'"{basename}"'
                         )
-                        lines.append("expressions({0})".format(comp_name))
+                        lines.append(f"expressions({comp_name})")
 
                     # Just add the comment
                     else:
                         lines.append("")
-                        lines.append('comment("{0}")'.format(obj))
+                        lines.append(f'comment("{obj}")')
 
         lines.append("")
         # Use Python code generator to indent outputted code
@@ -523,7 +565,7 @@ class ODE(ODEComponent):
 
             # If a state is substituted by a state solution
             if isinstance(dup_obj, State) and isinstance(obj, StateSolution):
-                debug("Reduce state '{0}' to {1}".format(dup_obj, obj.expr))
+                debug(f"Reduce state '{dup_obj}' to {obj.expr}")
 
             # If duplicated object is an ODE Parameter and the added object is
             # either a State or a Parameter we replace the Parameter.
@@ -534,7 +576,7 @@ class ODE(ODEComponent):
                 and isinstance(obj, (State, Parameter))
             ):
 
-                timer = Timer("Replace objects")
+                timer = Timer("Replace objects")  # noqa: F841
 
                 # Remove the object
                 self.ode_objects.remove(dup_obj)
@@ -579,7 +621,7 @@ class ODE(ODEComponent):
             ):
                 error(
                     "Cannot replace an ODE parameter with an Expression, "
-                    "only with Parameters and States."
+                    "only with Parameters and States.",
                 )
 
             # If State, Parameter or DerivativeExpression we always raise an error
@@ -601,8 +643,10 @@ class ODE(ODEComponent):
                 error(
                     "Cannot register {0}. A {1} with name '{2}' is "
                     "already registered in this ODE.".format(
-                        type(obj).__name__, type(dup_obj).__name__, dup_obj.name
-                    )
+                        type(obj).__name__,
+                        type(dup_obj).__name__,
+                        dup_obj.name,
+                    ),
                 )
             else:
 
@@ -635,7 +679,11 @@ class ODE(ODEComponent):
             derivative_expression_list.sort(key=lambda e: e.sort_key())
             for der_expr in derivative_expression_list:
                 expression_added |= self._expand_single_derivative(
-                    comp, obj, der_expr, replace_dict, dependent
+                    comp,
+                    obj,
+                    der_expr,
+                    replace_dict,
+                    dependent,
                 )
 
             # If expressions need to be re-created
@@ -660,7 +708,7 @@ class ODE(ODEComponent):
                 if dep_obj is None:
                     error(
                         "The symbol '{0}' is not declared within the '{1}' "
-                        "ODE.".format(sym, self.name)
+                        "ODE.".format(sym, self.name),
                     )
 
                 # Store object dependencies
@@ -674,8 +722,9 @@ class ODE(ODEComponent):
                 error(
                     "A state solution cannot have been used in "
                     "any previous expressions. {0} is used in: {1}".format(
-                        obj.state, used_in
-                    )
+                        obj.state,
+                        used_in,
+                    ),
                 )
 
     def expanded_expression(self, expr):
@@ -687,7 +736,7 @@ class ODE(ODEComponent):
         IndexedObjects)
         """
 
-        timer = Timer("Expand expression")
+        timer = Timer("Expand expression")  # noqa: F841
 
         check_arg(expr, Expression)
 
@@ -751,11 +800,11 @@ class ODE(ODEComponent):
             if len(components) > 1:
                 error(
                     "{0} are not a components of this ODE.".format(
-                        ", ".join("'{0}'".format(comp) for comp in components)
-                    )
+                        ", ".join("'{0}'".format(comp) for comp in components),
+                    ),
                 )
             else:
-                error("'{0}' is not a component of this ODE.".format(components[0]))
+                error(f"'{components[0]}' is not a component of this ODE.")
 
         # Collect dependencies
         included_objects = []
@@ -819,7 +868,7 @@ class ODE(ODEComponent):
             if comp not in collected_components:
                 continue
 
-            comp_comment = "Expressions for the {0} " "component".format(comp.name)
+            comp_comment = f"Expressions for the {comp.name} component"
 
             # Get corresponding component in new ODE
             added = old_new_map[comp]
@@ -846,7 +895,9 @@ class ODE(ODEComponent):
 
                             states = obj.states
                             added._add_single_rate(
-                                states[0].sym, states[1].sym, new_expr
+                                states[0].sym,
+                                states[1].sym,
+                                new_expr,
                             )
                             continue
 
@@ -998,7 +1049,7 @@ class ODE(ODEComponent):
             self.all_expr_components_ordered.append(comp.name)
 
             # Add a comment to the component
-            comp.add_comment("Expressions for the {0} " "component".format(comp.name))
+            comp.add_comment(f"Expressions for the {comp.name} component")
 
             # Recount the last added expression so the comment comes
             # infront of the expression
@@ -1016,7 +1067,7 @@ class ODE(ODEComponent):
             self.all_expr_components_ordered.append(comp.name)
 
             # Add a comment to the component
-            comp.add_comment("Expressions for the {0} " "component".format(comp.name))
+            comp.add_comment(f"Expressions for the {comp.name} component")
 
             # Recount the last added expression so the comment comes
             # infront of the expression
@@ -1048,13 +1099,13 @@ class ODE(ODEComponent):
         if not isinstance(der_expr.args[0], AppliedUndef):
             error(
                 "Can only register Derivatives of allready registered "
-                "Expressions. Got: {0}".format(sympycode(der_expr.args[0]))
+                "Expressions. Got: {0}".format(sympycode(der_expr.args[0])),
             )
 
         if not isinstance(der_expr.args[1], (AppliedUndef, sp.Symbol)):
             error(
                 "Can only register Derivatives with a single dependent "
-                "variabe. Got: {0}".format(sympycode(der_expr.args[1]))
+                "variabe. Got: {0}".format(sympycode(der_expr.args[1])),
             )
 
         # Get the expr and dependent variable objects
@@ -1068,8 +1119,9 @@ class ODE(ODEComponent):
             error(
                 "The expression {0} is dependent on the state "
                 "derivative of {1} which is not registered in this ODE.".format(
-                    obj, expr_obj
-                )
+                    obj,
+                    expr_obj,
+                ),
             )
 
         # If we get a Derivative(expr, t) we issue an error
@@ -1081,7 +1133,7 @@ class ODE(ODEComponent):
         if not isinstance(expr_obj, Expression):
             error(
                 "Can only differentiate expressions or states. Got {0} as "
-                "the derivative expression.".format(expr_obj)
+                "the derivative expression.".format(expr_obj),
             )
 
         # Expand derivative and see if it is trivial
