@@ -17,23 +17,47 @@
 
 __all__ = ["ODEComponent"]
 
+import weakref
+
 # System imports
 from collections import OrderedDict, defaultdict
-import weakref
-from functools import partial
 
-from sympy.core.function import AppliedUndef
+from modelparameters.codegeneration import _all_keywords, sympycode
+
+# Local imports
+from modelparameters.logger import debug, error
 
 # ModelParameters imports
 from modelparameters.sympytools import sp, symbols_from_expr
-from modelparameters.utils import Timer
-from modelparameters.codegeneration import sympycode, _all_keywords
+from modelparameters.utils import Timer, check_arg, scalars
+from sympy.core.function import AppliedUndef
 
-# Local imports
-from gotran.common import error, debug, check_arg, check_kwarg, scalars
-from gotran.model.odeobjects import *
-from gotran.model.expressions import *
-from gotran.model.utils import *
+from .expressions import (
+    AlgebraicExpression,
+    DerivativeExpression,
+    Expression,
+    IndexedExpression,
+    IndexedObject,
+    Intermediate,
+    RateExpression,
+    State,
+    StateDerivative,
+    StateExpression,
+    StateSolution,
+)
+from .odeobjects import Comment, ODEObject, Parameter
+from .utils import (
+    ALGEBRAIC_EXPRESSION,
+    DERIVATIVE_EXPRESSION,
+    INTERMEDIATE,
+    STATE_SOLUTION_EXPRESSION,
+    ODEObjectList,
+    RateDict,
+    iter_objects,
+    ode_components,
+    ode_objects,
+    special_expression,
+)
 
 
 class ODEComponent(ODEObject):
@@ -164,7 +188,7 @@ class ODEComponent(ODEObject):
         init : scalar, modelparameters.ScalarParam
             The initial value of the state
         """
-        timer = Timer("Add states")
+        timer = Timer("Add states")  # noqa: F841
 
         # Create state
         state = State(name, init, self.time)
@@ -196,7 +220,7 @@ class ODEComponent(ODEObject):
             if not isinstance(arg, tuple) or len(arg) != 2:
                 error(
                     "excpected tuple with lenght 2 with state name (str) "
-                    "and init values as the args argument."
+                    "and init values as the args argument.",
                 )
             state_name, init = arg
 
@@ -214,7 +238,7 @@ class ODEComponent(ODEObject):
         init : scalar, modelparameters.ScalarParam
             The initial value of the parameter
         """
-        timer = Timer("Add parameters")
+        timer = Timer("Add parameters")  # noqa: F841
 
         param = Parameter(name, init)
 
@@ -245,7 +269,7 @@ class ODEComponent(ODEObject):
             if not isinstance(arg, tuple) or len(arg) != 2:
                 error(
                     "excpected tuple with lenght 2 with parameter name (str) "
-                    "and init values as the args argument."
+                    "and init values as the args argument.",
                 )
             parameter_name, value = arg
 
@@ -260,7 +284,7 @@ class ODEComponent(ODEObject):
         comp = ODEComponent(name, self)
 
         if name in self.root.all_components:
-            error("A component with the name '{0}' already excists.".format(name))
+            error(f"A component with the name '{name}' already excists.")
 
         self.children[comp.name] = comp
         self.root.all_components[comp.name] = comp
@@ -299,13 +323,13 @@ class ODEComponent(ODEObject):
             if (state.sym is not sym) and (state.sym in sym.atoms()):
                 error(
                     "{0}, a sub expression of the expression, cannot depend "
-                    "on the state for which we try to solve for.".format(sym)
+                    "on the state for which we try to solve for.".format(sym),
                 )
 
         # Try solve the passed expr
         try:
             solved_expr = sp.solve(expr, state.sym)
-        except:
+        except Exception:
             error("Could not solve the passed expression")
 
         assert isinstance(solved_expr, list)
@@ -336,16 +360,16 @@ class ODEComponent(ODEObject):
 
         state = self._expect_state(state)
 
-        if "d{0}_dt".format(state.name) in self.ode_objects:
+        if f"d{state.name}_dt" in self.ode_objects:
             error(
                 "Cannot registered a state solution for a state "
-                "that has a state derivative registered."
+                "that has a state derivative registered.",
             )
 
-        if "alg_{0}_0".format(state.name) in self.ode_objects:
+        if f"alg_{state.name}_0" in self.ode_objects:
             error(
                 "Cannot registered a state solution for a state "
-                "that has an algebraic expression registered."
+                "that has an algebraic expression registered.",
             )
 
         # Create a StateSolution in the present component
@@ -369,7 +393,7 @@ class ODEComponent(ODEObject):
         """
 
         # Create an Intermediate in the present component
-        timer = Timer("Add intermediate")
+        timer = Timer("Add intermediate")  # noqa: F841
         expr = Intermediate(name, expr, dependent)
 
         self._register_component_object(expr, dependent)
@@ -392,21 +416,21 @@ class ODEComponent(ODEObject):
             If given the count of this expression will follow as a
             fractional count based on the count of the dependent object
         """
-        timer = Timer("Add derivatives")
+        timer = Timer("Add derivatives")  # noqa: F841
 
         if isinstance(der_expr, AppliedUndef):
             name = sympycode(der_expr)
             der_expr = self.root.present_ode_objects.get(name)
 
             if der_expr is None:
-                error("{0} is not registered in this ODE".format(name))
+                error(f"{name} is not registered in this ODE")
 
         if isinstance(dep_var, (AppliedUndef, sp.Symbol)):
             name = sympycode(dep_var)
             dep_var = self.root.present_ode_objects.get(name)
 
             if dep_var is None:
-                error("{0} is not registered in this ODE".format(name))
+                error(f"{name} is not registered in this ODE")
 
         # Check if der_expr is a State
         if isinstance(der_expr, State):
@@ -440,16 +464,16 @@ class ODEComponent(ODEObject):
 
         state = self._expect_state(state)
 
-        if "d{0}_dt".format(state.name) in self.ode_objects:
+        if f"d{state.name}_dt" in self.ode_objects:
             error(
                 "Cannot registered an algebraic expression for a state "
-                "that has a state derivative registered."
+                "that has a state derivative registered.",
             )
 
         if state.is_solved:
             error(
                 "Cannot registered an algebraic expression for a state "
-                "which is registered solved."
+                "which is registered solved.",
             )
 
         # Create an AlgebraicExpression in the present component
@@ -631,7 +655,7 @@ class ODEComponent(ODEObject):
         ):
             debug(
                 "Not registering: {0} as attribut. It does not contain "
-                "any symbols or scalars.".format(name)
+                "any symbols or scalars.".format(name),
             )
 
             # FIXME: Should we raise an error?
@@ -664,7 +688,7 @@ class ODEComponent(ODEObject):
         elif TYPE == ALGEBRAIC_EXPRESSION:
 
             # Try getting corresponding ODEObjects
-            var_name, = expr.groups()
+            (var_name,) = expr.groups()
             var_obj = self.root.present_ode_objects.get(var_name)
 
             if var_obj is None:
@@ -687,7 +711,7 @@ class ODEComponent(ODEObject):
 
         if comp is None:
             comp = self.add_component(name)
-            debug("Adding '{0}' component to {1}".format(name, self))
+            debug(f"Adding '{name}' component to {self}")
         else:
             self.root._present_component = comp.name
 
@@ -709,20 +733,20 @@ class ODEComponent(ODEObject):
             state = self.root.present_ode_objects.get(name)
 
             if state is None:
-                error("{} is not registered in this ODE".format(name))
+                error(f"{name} is not registered in this ODE")
 
             if only_local_states and not (
                 state in self.states
                 or (state in self.intermediates and allow_state_solution)
             ):
-                error("{} is not registered in component {}".format(name, self.name))
+                error(f"{name} is not registered in component {self.name}")
 
         check_arg(state, allowed, 0)
 
         if isinstance(state, State) and state.is_solved:
             error(
                 "Cannot registered a state expression for a state "
-                "which is registered solved."
+                "which is registered solved.",
             )
 
         return state
@@ -735,7 +759,7 @@ class ODEComponent(ODEObject):
         if self._is_finalized:
             error(
                 "Cannot add {0} {1} to component {2} it is "
-                "already finalized.".format(obj.__class__.__name__, obj, self)
+                "already finalized.".format(obj.__class__.__name__, obj, self),
             )
 
         self._check_reserved_wordings(obj)
@@ -751,13 +775,13 @@ class ODEComponent(ODEObject):
                 error(
                     "A component cannot have both state expressions "
                     "(derivative and algebraic expressions) and rate "
-                    "expressions."
+                    "expressions.",
                 )
 
             if obj.state in self._local_state_expressions:
                 error(
                     "A StateExpression for state {0} is already registered "
-                    "in this component.".format(obj.state.name)
+                    "in this component.".format(obj.state.name),
                 )
 
             # Check that the state is registered in this component
@@ -765,7 +789,7 @@ class ODEComponent(ODEObject):
             if not isinstance(state_obj, State):
                 error(
                     "The state expression {0} defines state {1}, which is "
-                    "not registered in the {2} component.".format(obj, obj.state, self)
+                    "not registered in the {2} component.".format(obj, obj.state, self),
                 )
 
             self._local_state_expressions[obj.state] = obj
@@ -777,7 +801,8 @@ class ODEComponent(ODEObject):
             # If indexed expression or object register the basename as a dict
             if isinstance(obj, (IndexedExpression, IndexedObject)):
                 if obj.basename in self.__dict__ and isinstance(
-                    self.__dict__[obj.basename], dict
+                    self.__dict__[obj.basename],
+                    dict,
                 ):
                     self.__dict__[obj.basename][obj.indices] = obj.sym
                 else:
@@ -795,7 +820,7 @@ class ODEComponent(ODEObject):
         if obj.name in _all_keywords:
             error(
                 "Cannot register a {0} with a computer language "
-                "keyword name: {1}".format(obj.__class__.__name__, obj.name)
+                "keyword name: {1}".format(obj.__class__.__name__, obj.name),
             )
 
         # Check for reserved Expression wordings
@@ -840,9 +865,6 @@ class ODEComponent(ODEObject):
         ):
             error("expected a tuple of 2 lists with states as the " "states argument")
 
-        # Get all states associated with this Markov model
-        local_states = self.states
-
         # Check index arguments
         # for list_of_states in states:
         #    print list_of_states, local_states
@@ -853,7 +875,7 @@ class ODEComponent(ODEObject):
         # Check that the length of the state lists corresponds with the shape of
         # the rate matrix
         if rate_matrix.shape[0] != len(states[0]) or rate_matrix.shape[1] != len(
-            states[1]
+            states[1],
         ):
             error("Shape of rates does not match given states")
 
@@ -881,7 +903,7 @@ class ODEComponent(ODEObject):
         if self.state_expressions:
             error(
                 "A component cannot have both state expressions (derivative "
-                "and algebraic expressions) and rate expressions."
+                "and algebraic expressions) and rate expressions.",
             )
 
         check_arg(expr, scalars + (sp.Basic,), 2, ODEComponent._add_single_rate)
@@ -889,10 +911,14 @@ class ODEComponent(ODEObject):
         expr = sp.sympify(expr)
 
         to_state = self._expect_state(
-            to_state, allow_state_solution=True, only_local_states=True
+            to_state,
+            allow_state_solution=True,
+            only_local_states=True,
         )
         from_state = self._expect_state(
-            from_state, allow_state_solution=True, only_local_states=True
+            from_state,
+            allow_state_solution=True,
+            only_local_states=True,
         )
 
         if to_state == from_state:
@@ -900,8 +926,7 @@ class ODEComponent(ODEObject):
 
         if (to_state.sym, from_state.sym) in self.rates:
             error(
-                "Rate between state {0} and {1} is already "
-                "registered.".format(from_state, to_state)
+                f"Rate between state {from_state} and {to_state} is already registered.",
             )
 
         # FIXME: It should also not be possible to include other
@@ -909,7 +934,7 @@ class ODEComponent(ODEObject):
         syms_expr = symbols_from_expr(expr)
         if to_state.sym in syms_expr or from_state.sym in syms_expr:
             error(
-                "The rate expression cannot be dependent on the " "states it connects."
+                "The rate expression cannot be dependent on the " "states it connects.",
             )
 
         # Create a RateExpression
@@ -938,13 +963,13 @@ class ODEComponent(ODEObject):
             incomplete_states = []
             for obj in self.ode_objects:
                 if isinstance(obj, State):
-                    if not obj in self._local_state_expressions:
+                    if obj not in self._local_state_expressions:
                         incomplete_states.append(obj)
 
             incomplete_state_names = [s.name for s in incomplete_states]
 
-            msg = "Cannot finalize component '{0}'. ".format(self)
-            msg += "Missing time derivatives for the following states: {}".format(', '.join(incomplete_state_names))
+            msg = f"Cannot finalize component '{self}'. "
+            msg += f"Missing time derivatives for the following states: {', '.join(incomplete_state_names)}"
 
             error(msg)
 
@@ -990,16 +1015,17 @@ class ODEComponent(ODEObject):
 
         # Check used states
         if 0 in used_states:
-            error(
-                "No rate registered for state {0}".format(states[used_states.find(0)])
-            )
+            error(f"No rate registered for state {states[used_states.find(0)]}")
 
         # Check rate symetry
         for (ind_from, ind_to), times in list(rate_check.items()):
             if times != 2:
                 error(
                     "Only one rate between the states {0} and {1} was "
-                    "registered, expected two.".format(states[ind_from], states[ind_to])
+                    "registered, expected two.".format(
+                        states[ind_from],
+                        states[ind_to],
+                    ),
                 )
 
         # Add derivatives
